@@ -96,8 +96,14 @@ typedef enum
   GSD_POWER_ACTION_SUSPEND,
   GSD_POWER_ACTION_SHUTDOWN,
   GSD_POWER_ACTION_HIBERNATE,
-  GSD_POWER_ACTION_INTERACTIVE,
   GSD_POWER_ACTION_NOTHING
 } GsdPowerActionType;
 
+typedef enum
+{
+  GSD_UPDATE_TYPE_ALL,
+  GSD_UPDATE_TYPE_SECURITY,
+  GSD_UPDATE_TYPE_NONE
+} GsdUpdateType;
+
 #endif /* __gsd_enums_h__ */
