@@ -72,6 +72,7 @@
 
 struct GsdKeyboardManagerPrivate
 {
+	guint      start_idle_id;
         GSettings *settings;
         gboolean   have_xkb;
         gint       xkb_event_base;
@@ -350,7 +351,7 @@ apply_settings (GSettings          *settings,
 #endif /* HAVE_X11_EXTENSIONS_XKB_H */
 
         XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-        gdk_error_trap_pop ();
+        gdk_error_trap_pop_ignored ();
 }
 
 void
@@ -388,6 +389,8 @@ start_keyboard_idle_cb (GsdKeyboardManager *manager)
 
         gnome_settings_profile_end (NULL);
 
+        manager->priv->start_idle_id = 0;
+
         return FALSE;
 }
 
@@ -397,7 +400,7 @@ gsd_keyboard_manager_start (GsdKeyboardManager *manager,
 {
         gnome_settings_profile_start (NULL);
 
-        g_idle_add ((GSourceFunc) start_keyboard_idle_cb, manager);
+        manager->priv->start_idle_id = g_idle_add ((GSourceFunc) start_keyboard_idle_cb, manager);
 
         gnome_settings_profile_end (NULL);
 
@@ -433,10 +436,6 @@ gsd_keyboard_manager_set_property (GObject        *object,
                                    const GValue   *value,
                                    GParamSpec     *pspec)
 {
-        GsdKeyboardManager *self;
-
-        self = GSD_KEYBOARD_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -450,10 +449,6 @@ gsd_keyboard_manager_get_property (GObject        *object,
                                    GValue         *value,
                                    GParamSpec     *pspec)
 {
-        GsdKeyboardManager *self;
-
-        self = GSD_KEYBOARD_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -467,9 +462,6 @@ gsd_keyboard_manager_constructor (GType                  type,
                                   GObjectConstructParam *construct_properties)
 {
         GsdKeyboardManager      *keyboard_manager;
-        GsdKeyboardManagerClass *klass;
-
-        klass = GSD_KEYBOARD_MANAGER_CLASS (g_type_class_peek (GSD_TYPE_KEYBOARD_MANAGER));
 
         keyboard_manager = GSD_KEYBOARD_MANAGER (G_OBJECT_CLASS (gsd_keyboard_manager_parent_class)->constructor (type,
                                                                                                       n_construct_properties,
@@ -481,10 +473,6 @@ gsd_keyboard_manager_constructor (GType                  type,
 static void
 gsd_keyboard_manager_dispose (GObject *object)
 {
-        GsdKeyboardManager *keyboard_manager;
-
-        keyboard_manager = GSD_KEYBOARD_MANAGER (object);
-
         G_OBJECT_CLASS (gsd_keyboard_manager_parent_class)->dispose (object);
 }
 
@@ -520,6 +508,9 @@ gsd_keyboard_manager_finalize (GObject *object)
 
         g_return_if_fail (keyboard_manager->priv != NULL);
 
+        if (keyboard_manager->priv->start_idle_id != 0)
+                g_source_remove (keyboard_manager->priv->start_idle_id);
+
         G_OBJECT_CLASS (gsd_keyboard_manager_parent_class)->finalize (object);
 }
 
